Thrift-1435: make TException.Message property conformant to the usual expectations
Client: delphi
Patch: Jens Geyer

Make delphi exceptions act like standard TException within other languages 



git-svn-id: https://svn.apache.org/repos/asf/thrift/trunk@1205415 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/lib/delphi/src/Thrift.pas b/lib/delphi/src/Thrift.pas
index 50513d3..dceb256 100644
--- a/lib/delphi/src/Thrift.pas
+++ b/lib/delphi/src/Thrift.pas
@@ -60,17 +60,26 @@
   // base class for IDL-generated exceptions
   TException = class( SysUtils.Exception)
   public
-    procedure Message;  // hide inherited property to prevent accidental read/write
+    function Message : string;        // hide inherited property: allow read, but prevent accidental writes
+    procedure UpdateMessageProperty;  // update inherited message property with toString()
   end;
 
 implementation
 
 { TException }
 
-procedure TException.Message;
-// hide inherited property to prevent accidental read/write
+function TException.Message;
+// allow read (exception summary), but prevent accidental writes
+// read will return the exception summary
 begin
-  ASSERT( FALSE, 'Unexpected call to '+ClassName+'.message. Forgot the underscore?');
+  result := Self.ToString;
+end;
+
+procedure TException.UpdateMessageProperty;
+// Update the inherited Message property to better conform to standard behaviour.
+// Nice benefit: The IDE is now able to show the exception message again.
+begin
+  inherited Message := Self.ToString;  // produces a summary text
 end;
 
 { TApplicationException }